summaryrefslogtreecommitdiffstats
path: root/sw
diff options
context:
space:
mode:
authorMichael Stahl <mstahl@redhat.com>2012-01-20 21:43:05 +0100
committerMichael Stahl <mstahl@redhat.com>2012-01-20 21:47:32 +0100
commitabc07e01b78d255e0ce9658e779275ffe7c4d1e2 (patch)
treeac8344a446f9d6ab202190550e3f413c414a67ac /sw
parentTranslate German comments (diff)
downloadcore-abc07e01b78d255e0ce9658e779275ffe7c4d1e2.tar.gz
core-abc07e01b78d255e0ce9658e779275ffe7c4d1e2.zip
sw: tweak translations
Diffstat (limited to 'sw')
-rw-r--r--sw/source/core/doc/docredln.cxx28
-rw-r--r--sw/source/core/doc/doctxm.cxx6
-rw-r--r--sw/source/core/doc/ftnidx.cxx7
-rw-r--r--sw/source/core/doc/tblcpy.cxx8
4 files changed, 24 insertions, 25 deletions
diff --git a/sw/source/core/doc/doctxm.cxx b/sw/source/core/doc/doctxm.cxx
index e738fe586a27..23f03873e02a 100644
--- a/sw/source/core/doc/doctxm.cxx
+++ b/sw/source/core/doc/doctxm.cxx
@@ -1181,7 +1181,7 @@ void SwTOXBaseSection::UpdateMarks( const SwTOXInternational& rIntl,
SwTOXSortTabBase* pBase = 0;
if(TOX_INDEX == eTOXTyp)
{
- // Keyword section mark
+ // index entry mark
lang::Locale aLocale;
if ( pBreakIt->GetBreakIter().is() )
{
@@ -1208,7 +1208,7 @@ void SwTOXBaseSection::UpdateMarks( const SwTOXInternational& rIntl,
}
else if( TOX_USER == eTOXTyp ||
pMark->GetLevel() <= GetLevel())
- { // Content section mark
+ { // table of content mark
// also used for user marks
pBase = new SwTOXContent( *pTOXSrc, pTxtMark, rIntl );
InsertSorted(pBase);
@@ -1680,7 +1680,7 @@ void SwTOXBaseSection::GenerateText( sal_uInt16 nArrayIdx,
if( aNdRect.IsEmpty() )
{
- // Nothing helped so far, so we go via the PageTemplate
+ // Nothing helped so far, so we go via the PageDesc
sal_uInt32 nPgDescNdIdx = pTOXNd->GetIndex() + 1;
sal_uInt32* pPgDescNdIdx = &nPgDescNdIdx;
pPageDesc = pTOXNd->FindPageDesc( sal_False, pPgDescNdIdx );
diff --git a/sw/source/core/doc/ftnidx.cxx b/sw/source/core/doc/ftnidx.cxx
index 382abd38aead..3ccd856bb772 100644
--- a/sw/source/core/doc/ftnidx.cxx
+++ b/sw/source/core/doc/ftnidx.cxx
@@ -93,8 +93,8 @@ void SwFtnIdxs::UpdateFtn( const SwNodeIndex& rStt )
const SwEndNoteInfo& rEndInfo = pDoc->GetEndNoteInfo();
const SwFtnInfo& rFtnInfo = pDoc->GetFtnInfo();
- // For normal foot notes we treat chapter and document-wise numbering
- // seperately. For Endnotes we only have chapter-wise numbering.
+ // For normal foot notes we treat per-chapter and per-document numbering
+ // seperately. For Endnotes we only have per-document numbering.
if( FTNNUM_CHAPTER == rFtnInfo.eNum )
{
const SwOutlineNodes& rOutlNds = pDoc->GetNodes().GetOutLineNds();
@@ -153,7 +153,7 @@ void SwFtnIdxs::UpdateFtn( const SwNodeIndex& rStt )
SwUpdFtnEndNtAtEnd aNumArr;
- // sal_Bool, so that also go through the Endnotes with chapter setting enabled
+ // unless we have per-document numbering, only look at endnotes here
const sal_Bool bEndNoteOnly = FTNNUM_DOC != rFtnInfo.eNum;
sal_uInt16 nPos, nFtnNo = 1, nEndNo = 1;
@@ -199,7 +199,6 @@ void SwFtnIdxs::UpdateFtn( const SwNodeIndex& rStt )
}
}
}
- // Pageweise wird vom MA erfuellt !!
}
diff --git a/sw/source/core/doc/tblcpy.cxx b/sw/source/core/doc/tblcpy.cxx
index 070a42fbfb1e..956a42c8afe9 100644
--- a/sw/source/core/doc/tblcpy.cxx
+++ b/sw/source/core/doc/tblcpy.cxx
@@ -586,8 +586,8 @@ void lcl_CpyBox( const SwTable& rCpyTbl, const SwTableBox* pCpyBox,
}
}
- // If DestBox is a Headline Box and has TableTemplate set, then
- // DO NOT automatically set the TableHeadline Template!
+ // If DestBox is a Headline Box and has Table style set, then
+ // DO NOT automatically set the TableHeadline style!
if( 1 < rDstTbl.GetTabLines().Count() &&
pLine == rDstTbl.GetTabLines()[0] )
{
@@ -628,7 +628,7 @@ void lcl_CpyBox( const SwTable& rCpyTbl, const SwTableBox* pCpyBox,
RES_POOLCOLL_TABLE == nPoolId
? RES_POOLCOLL_TABLE_HDLN
: RES_POOLCOLL_TABLE ) );
- if( pColl ) // Apply Template
+ if( pColl ) // Apply style
{
SwPaM aPam( aSavePos );
aPam.SetMark();
@@ -939,7 +939,7 @@ sal_Bool SwTable::InsTable( const SwTable& rCpyTbl, const SwSelBoxes& rSelBoxes,
SwTableLine* pCpyLn = rCpyTbl.GetTabLines()[ nLn %
rCpyTbl.GetTabLines().Count() ];
- // Selected too less rows?
+ // Selected too few rows?
if( pInsFLine )
{
// We insert a new row into the FndBox
diff --git a/sw/source/core/doc/docredln.cxx b/sw/source/core/doc/docredln.cxx
index ba47d2c1454d..243964c3474f 100644
--- a/sw/source/core/doc/docredln.cxx
+++ b/sw/source/core/doc/docredln.cxx
@@ -172,7 +172,7 @@ void SwDoc::SetRedlineMode( RedlineMode_t eMode )
{
bool bSaveInXMLImportFlag = IsInXMLImport();
SetInXMLImport( false );
- // and then hide everything, display it
+ // and then hide/display everything
void (SwRedline::*pFnc)( sal_uInt16 ) = 0;
switch( nsRedlineMode_t::REDLINE_SHOW_MASK & eMode )
@@ -280,7 +280,7 @@ bool CheckPosition( const SwPosition* pStt, const SwPosition* pEnd )
/*
-Text means Text not "poluted" by Redlines.
+Text means Text not "polluted" by Redlines.
Behaviour of Insert-Redline:
@@ -1138,7 +1138,7 @@ bool SwDoc::AppendRedline( SwRedline* pNewRedl, bool bCallDelete )
case POS_INSIDE:
if( pRedl->IsOwnRedline( *pNewRedl ) &&
pRedl->CanCombine( *pNewRedl ))
- // an own can be ignored completely
+ // own one can be ignored completely
delete pNewRedl, pNewRedl = 0;
else if( *pREnd == *pEnd )
@@ -1796,7 +1796,7 @@ sal_Bool lcl_RejectRedline( SwRedlineTbl& rArr, sal_uInt16& rPos,
case POS_OUTSIDE:
case POS_EQUAL:
{
// delete the area again
rArr.Remove( rPos-- );
bDelRedl = sal_True;
if( bCallDelete )
@@ -2025,7 +2025,7 @@ int lcl_AcceptRejectRedl( Fn_AcceptReject fn_AcceptReject,
void lcl_AdjustRedlineRange( SwPaM& rPam )
{
- // The Selection is only in the ContentArea. If there are Redlines
+ // The Selection is only in the ContentSection. If there are Redlines
// to Non-ContentNodes before or after that, then the Selections
// expand to them.
SwPosition* pStt = rPam.Start(),
@@ -2133,7 +2133,7 @@ bool SwDoc::AcceptRedline( const SwPaM& rPam, bool bCallDelete )
(nsRedlineMode_t::REDLINE_SHOW_MASK & eRedlineMode) )
SetRedlineMode( (RedlineMode_t)(nsRedlineMode_t::REDLINE_SHOW_INSERT | nsRedlineMode_t::REDLINE_SHOW_DELETE | eRedlineMode));
- // The Selection is only in the ContentArea. If there are Redlines
+ // The Selection is only in the ContentSection. If there are Redlines
// to Non-ContentNodes before or after that, then the Selections
// expand to them.
SwPaM aPam( *rPam.GetMark(), *rPam.GetPoint() );
@@ -2243,7 +2243,7 @@ bool SwDoc::RejectRedline( const SwPaM& rPam, bool bCallDelete )
(nsRedlineMode_t::REDLINE_SHOW_MASK & eRedlineMode) )
SetRedlineMode((RedlineMode_t)(nsRedlineMode_t::REDLINE_SHOW_INSERT | nsRedlineMode_t::REDLINE_SHOW_DELETE | eRedlineMode));
- // The Selection is only in the ContentArea. If there are Redlines
+ // The Selection is only in the ContentSection. If there are Redlines
// to Non-ContentNodes before or after that, then the Selections
// expand to them.
SwPaM aPam( *rPam.GetMark(), *rPam.GetPoint() );
@@ -2408,7 +2408,7 @@ const SwRedline* SwDoc::SelPrevRedline( SwPaM& rPam ) const
sal_Bool bRestart;
// If the starting positon points to the last valid ContentNode,
- // we take the next Redline in any case.
+ // we take the previous Redline in any case.
sal_uInt16 n = 0;
const SwRedline* pFnd = lcl_FindCurrRedline( rSttPos, n, sal_False );
if( pFnd )
@@ -2608,7 +2608,7 @@ sal_Bool SwRedlineTbl::Insert( SwRedlinePtr& p, sal_Bool bIns )
bRet = InsertWithValidRanges( p );
else
{
- OSL_ENSURE( !this, "Redline: wrong Area" );
+ OSL_ENSURE( !this, "Redline: wrong range" );
}
return bRet;
}
@@ -2625,14 +2625,14 @@ sal_Bool SwRedlineTbl::Insert( SwRedlinePtr& p, sal_uInt16& rP, sal_Bool bIns )
bRet = InsertWithValidRanges( p, &rP );
else
{
- OSL_ENSURE( !this, "Redline: wrong Area" );
+ OSL_ENSURE( !this, "Redline: wrong range" );
}
return bRet;
}
sal_Bool SwRedlineTbl::InsertWithValidRanges( SwRedlinePtr& p, sal_uInt16* pInsPos )
{
- // Create valid "sub-areas" from the Selection
+ // Create valid "sub-ranges" from the Selection
sal_Bool bAnyIns = sal_False;
SwPosition* pStt = p->Start(),
* pEnd = pStt == p->GetPoint() ? p->GetMark() : p->GetPoint();
@@ -2888,7 +2888,7 @@ void SwRedlineExtraData_FmtColl::Reject( SwPaM& rPam ) const
if( pTNd->HasSwAttrSet() )
{
- // Only set those that are not there anymore. Others can
+ // Only set those that are not there anymore. Others
// could have changed, but we don't touch these.
SfxItemSet aTmp( *pSet );
aTmp.Differentiate( *pTNd->GetpSwAttrSet() );
@@ -3083,7 +3083,7 @@ SwRedline::~SwRedline()
{
if( pCntntSect )
{
- // delete the ContentArea
+ // delete the ContentSection
if( !GetDoc()->IsInDtor() )
GetDoc()->DeleteSection( &pCntntSect->GetNode() );
delete pCntntSect;
@@ -3414,7 +3414,7 @@ void SwRedline::CopyToSection()
SwPosition aPos( aNdIdx, SwIndex( pTxtNd ));
pDoc->CopyRange( *this, aPos, false );
- // Take over the Template from the EndNode if needed
+ // Take over the style from the EndNode if needed
// We don't want this in Doc::Copy
if( pCEndNd && pCEndNd != pCSttNd )
{
@@ -1796,7 +1796,7 @@ sal_Bool lcl_RejectRedline( SwRedlineTbl& rArr, sal_uInt16& rPos,
case POS_EQUAL:
{
- // delete the area again
+ // delete the range again
rArr.Remove( rPos-- );
bDelRedl = sal_True;